/** 
 *   Camera Control for STAR I.
 *
 *   (c) Copyright 2005 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

#ifndef _CAMERA_TOOLS_H
#define _CAMERA_TOOLS_H

#include "novas.h"
#include "fits_io.h"

#define CT_IM_OK         0
#define CT_IM_SETUP     -2 /* Error reading image setup */
#define CT_IM_DIM       -3 /* invalid dimension */
#define CT_IM_READ      -4 /* Error reading image */
#define CT_IM_FITS_ERR  -5 /* FITS Error */

#define DELTA_T (32.184 + 38.0) /* From National Earth Orientation
                                   Service (NEOS) */

int ct_read_save_file(int cam, char *filename);
int ct_read_header_file(struct image_2d *im, char *filename);
double strdeg2double(char *str);
int set_location(void);
double airmas(double z); /* implemented in airmas.h */
double mod24(double x);
int ct_precess(double from_date, double to_date,
	       double ra0,  double dec0,
	       double *ra1, double *dec1 );
int get_object_position(double *ra, double *dec);

extern site_info geo_loc;
#endif /* _CAMERA_TOOLS_H */
